@@ -89,7 +89,12 @@ class SqlContext(ExecutionContext):
         current_line = 1
         for i, stmt in enumerate(stmts):
             if stmt:
+                stmt = self.prepareStatement(stmt)
+                if not stmt:
+                    continue
+
                 logger.debug(u"Executing '%s ...'" % stmt[:50])
+
                 try:
                     cursor.execute(stmt.encode('utf-8'))
                     current_line += stmt.count('\n')
@@ -118,6 +123,7 @@ class SqlContext(ExecutionContext):
                     if onerror == u'abort' or syntaxerror:
                         logger.critical(u"Execution of %s%s generated an"
                                         u" error: %s", details, patch, errmsg)
+                        logger.debug(u"Statement: %s", stmt)
                         raise ExecutionError(u"Execution of %s%s generated an"
                                              u" error: %s" %
                                              (details, patch, errmsg))
@@ -136,6 +142,16 @@ class SqlContext(ExecutionContext):
 
         self.applied(patch)
 
+    def prepareStatement(self, statement):
+        """Possibly adjust the given `statement` before execution.
+
+        This implementation simply returns `statement.strip()`.
+        Subclasses may apply arbitrary transformations to it, or return
+        ``None`` to discard its execution.
+        """
+
+        return statement.strip()
+
     def classifyError(self, exc):
         """Determine the kind of error given its exception.
 
